/*Copyright (C) 2010-2012 Duncan Deveaux

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "SoundEngine.hpp"

SoundEngine::SoundEngine() : m_volume(100), m_manager(NULL)
{
    
}

void SoundEngine::playSound(const std::string &soundPath)
{
    m_playingSounds.push_back( loadSound(soundPath) );
    m_playingSounds.back().play();
}

void SoundEngine::update()
{
    std::list<Sound>::iterator it = m_playingSounds.begin();
    
    while (it != m_playingSounds.end())
    {
        if (!it->isPlaying())
            it = m_playingSounds.erase(it);
        else
            it++;
    }
}

void SoundEngine::setVolume(float volume)
{
    if (volume >= 0)
        m_volume = volume;
}

float SoundEngine::getVolume() const
{
    return m_volume;
}

void SoundEngine::setManager(SoundBufferManager &manager)
{
    m_manager = &manager;
}

const SoundBufferManager &SoundEngine::getManager() const
{
    return *m_manager;
}

Sound SoundEngine::loadSound(const std::string &soundPath)
{
    Sound sound;
    sound.setBuffer(*m_manager->getSoundBuffer(soundPath));
    sound.setVolume(m_volume);
    
    return sound;
}
