/*Copyright (C) 2010-2012 Duncan Deveaux

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DEF_CHOOSER
#define DEF_CHOOSER

#include "Widget.hpp"

#include "Graphics/Drawable/Text.hpp"
#include "Graphics/Drawable/Sprite.hpp"
#include <vector>

class Chooser : public Widget
{
    public:
        Chooser();
        void draw();
        
        bool mouseClick(const Vector &mouseCoords);
        bool mouseMove(const Vector &mouseCoords);
        
        void setData(const std::vector<std::string> &data, unsigned int selection = 0);
        const std::vector<std::string> &getData();
        
        unsigned int getSelection() const;
        
        //Get and set methods
        void setArrow(const Sprite &arrow);
        const Sprite &getArrow() const;
        
        void setContentWidth(float width);
        float getContentWidth() const;
        
        void setTextFont(Font &textFont);
        const Font &getTextFont() const;
        
        void setTextColor(const Color &textColor);
        const Color &getTextColor() const;
        
        float getWidth() const;
        float getHeight() const;
    
    private:
        void updateText();
        
        std::vector<std::string> m_dataList;
        unsigned int m_selection;
        
        Text m_textField;
        Sprite m_arrow;
        
        float m_contentWidth;
};

#endif
